@@ -1,6 +1,6 @@
 ###################################################
 #
-#  Copyright (C) 2008, 2009, 2010 Mario Kemper <mario.kemper@googlemail.com> and Shutter Team
+#  Copyright (C) 2008-2011 Mario Kemper <mario.kemper@googlemail.com> and Shutter Team
 #
 #  This file is part of Shutter.
 #
@@ -119,6 +119,12 @@ sub fct_ret_file_menu {
 
 	$self->{_menu_file}->append( Gtk2::SeparatorMenuItem->new );
 
+	#~ $self->{_menuitem_save} = Gtk2::ImageMenuItem->new_with_mnemonic( $d->get('_Save') );
+	#~ $self->{_menuitem_save}->set_image( Gtk2::Image->new_from_stock( 'gtk-save', 'menu' ) );
+	#~ $self->{_menuitem_save}->set_sensitive(FALSE);
+	#~ $self->{_menuitem_save}->add_accelerator( 'activate', $accel_group, Gtk2::Accelerator->parse('<Control>S'), qw/visible/ );
+	#~ $self->{_menu_file}->append( $self->{_menuitem_save} );
+
 	$self->{_menuitem_save_as} = Gtk2::ImageMenuItem->new_with_mnemonic( $d->get('Save _As...') );
 	$self->{_menuitem_save_as}->set_image( Gtk2::Image->new_from_stock( 'gtk-save-as', 'menu' ) );
 	$self->{_menuitem_save_as}->set_sensitive(FALSE);
@@ -127,7 +133,7 @@ sub fct_ret_file_menu {
 
 	#~ $self->{_menuitem_export_svg} = Gtk2::ImageMenuItem->new_with_mnemonic( $d->get('Export to SVG...') );
 	#~ $self->{_menuitem_export_svg}->set_sensitive(FALSE);
-	#~ $self->{_menuitem_export_svg}->add_accelerator( 'activate', $accel_group, Gtk2::Accelerator->parse('<Shift><Alt>S'), qw/visible/ );
+	#~ $self->{_menuitem_export_svg}->add_accelerator( 'activate', $accel_group, Gtk2::Accelerator->parse('<Shift><Alt>G'), qw/visible/ );
 	#~ $self->{_menu_file}->append( $self->{_menuitem_export_svg} );
 
 	$self->{_menuitem_export_pdf} = Gtk2::ImageMenuItem->new_with_mnemonic( $d->get('E_xport to PDF...') );
@@ -135,6 +141,11 @@ sub fct_ret_file_menu {
 	$self->{_menuitem_export_pdf}->add_accelerator( 'activate', $accel_group, Gtk2::Accelerator->parse('<Shift><Alt>P'), qw/visible/ );
 	$self->{_menu_file}->append( $self->{_menuitem_export_pdf} );
 
+	$self->{_menuitem_export_pscript} = Gtk2::ImageMenuItem->new_with_mnemonic( $d->get('Export to Post_Script...') );
+	$self->{_menuitem_export_pscript}->set_sensitive(FALSE);
+	$self->{_menuitem_export_pscript}->add_accelerator( 'activate', $accel_group, Gtk2::Accelerator->parse('<Shift><Alt>S'), qw/visible/ );
+	$self->{_menu_file}->append( $self->{_menuitem_export_pscript} );
+
 	$self->{_menu_file}->append( Gtk2::SeparatorMenuItem->new );
 
 	#~ $self->{_menuitem_pagesetup} = Gtk2::ImageMenuItem->new_from_stock('gtk-page-setup');
@@ -240,7 +251,7 @@ sub fct_ret_edit_menu {
 	$self->{_menu_edit}->append( Gtk2::SeparatorMenuItem->new );
 
 	$self->{_menuitem_settings} = Gtk2::ImageMenuItem->new_from_stock('gtk-preferences');
-	$self->{_menuitem_settings}->add_accelerator( 'activate', $accel_group, $Gtk2::Gdk::Keysyms{P}, qw/mod1-mask/, qw/visible/ );
+	$self->{_menuitem_settings}->add_accelerator( 'activate', $accel_group, Gtk2::Gdk->keyval_from_name('P'), qw/mod1-mask/, qw/visible/ );
 	$self->{_menu_edit}->append( $self->{_menuitem_settings} );
 
 	return $self->{_menu_edit};
@@ -308,21 +319,21 @@ sub fct_ret_session_menu {
 	$self->{_menu_session} = Gtk2::Menu->new();
 
 	$self->{_menuitem_back} = Gtk2::ImageMenuItem->new_from_stock('gtk-go-back');
-	$self->{_menuitem_back}->add_accelerator( 'activate', $accel_group, $Gtk2::Gdk::Keysyms{Left}, qw/mod1-mask/, qw/visible/ );
+	$self->{_menuitem_back}->add_accelerator( 'activate', $accel_group, Gtk2::Gdk->keyval_from_name('Left'), qw/mod1-mask/, qw/visible/ );
 	$self->{_menu_session}->append( $self->{_menuitem_back} );
 
 	$self->{_menuitem_forward} = Gtk2::ImageMenuItem->new_from_stock('gtk-go-forward');
-	$self->{_menuitem_forward}->add_accelerator( 'activate', $accel_group, $Gtk2::Gdk::Keysyms{Right}, qw/mod1-mask/, qw/visible/ );
+	$self->{_menuitem_forward}->add_accelerator( 'activate', $accel_group, Gtk2::Gdk->keyval_from_name('Right'), qw/mod1-mask/, qw/visible/ );
 	$self->{_menu_session}->append( $self->{_menuitem_forward} );
 
 	$self->{_menu_session}->append( Gtk2::SeparatorMenuItem->new );
 
 	$self->{_menuitem_first} = Gtk2::ImageMenuItem->new_from_stock('gtk-goto-first');
-	$self->{_menuitem_first}->add_accelerator( 'activate', $accel_group, $Gtk2::Gdk::Keysyms{Home}, qw/mod1-mask/, qw/visible/ );
+	$self->{_menuitem_first}->add_accelerator( 'activate', $accel_group, Gtk2::Gdk->keyval_from_name('Home'), qw/mod1-mask/, qw/visible/ );
 	$self->{_menu_session}->append( $self->{_menuitem_first} );
 
 	$self->{_menuitem_last} = Gtk2::ImageMenuItem->new_from_stock('gtk-goto-last');
-	$self->{_menuitem_last}->add_accelerator( 'activate', $accel_group, $Gtk2::Gdk::Keysyms{End}, qw/mod1-mask/, qw/visible/ );
+	$self->{_menuitem_last}->add_accelerator( 'activate', $accel_group, Gtk2::Gdk->keyval_from_name('End'), qw/mod1-mask/, qw/visible/ );
 	$self->{_menu_session}->append( $self->{_menuitem_last} );
 	
 	return $self->{_menu_session};
@@ -387,7 +398,7 @@ sub fct_ret_help_menu {
 	$self->{_menu_help}->append( Gtk2::SeparatorMenuItem->new );
 
 	$self->{_menuitem_about} = Gtk2::ImageMenuItem->new_from_stock('gtk-about');
-	$self->{_menuitem_about}->add_accelerator( 'activate', $accel_group, $Gtk2::Gdk::Keysyms{I}, qw/control-mask/, qw/visible/ );
+	$self->{_menuitem_about}->add_accelerator( 'activate', $accel_group, Gtk2::Gdk->keyval_from_name('I'), qw/control-mask/, qw/visible/ );
 	$self->{_menu_help}->append( $self->{_menuitem_about} );
 
 	return $self->{_menu_help};
@@ -417,7 +428,7 @@ sub fct_ret_new_menu {
 	$self->{_menuitem_selection} = Gtk2::ImageMenuItem->new_with_mnemonic( $d->get('_Selection') );
 	
 	eval{
-		my $ccursor_pb = Gtk2::Gdk::Cursor->new('crosshair')->get_image->scale_simple(Gtk2::IconSize->lookup('menu'), 'bilinear');
+		my $ccursor_pb = Gtk2::Gdk::Cursor->new('left_ptr')->get_image->scale_simple(Gtk2::IconSize->lookup('menu'), 'bilinear');
 		$self->{_menuitem_selection}->set_image( 
 			Gtk2::Image->new_from_pixbuf($ccursor_pb)
 		);	
@@ -437,16 +448,40 @@ sub fct_ret_new_menu {
 	}
 	$self->{_menu_new}->append( $self->{_menuitem_selection} );
 
-	$self->{_menu_new}->append( Gtk2::SeparatorMenuItem->new );
+	#~ $self->{_menu_new}->append( Gtk2::SeparatorMenuItem->new );
 
 	#full screen
-	$self->{_menuitem_full} = Gtk2::ImageMenuItem->new_from_stock( 'gtk-fullscreen' );
+	$self->{_menuitem_full} = Gtk2::ImageMenuItem->new_with_mnemonic( $d->get('_Desktop') );
+	if($icontheme->has_icon('user-desktop')){
+		$self->{_menuitem_full}->set_image( Gtk2::Image->new_from_icon_name( 'user-desktop', 'menu' ) );	
+	}elsif($icontheme->has_icon('desktop')){
+		$self->{_menuitem_full}->set_image( Gtk2::Image->new_from_icon_name( 'desktop', 'menu' ) );	
+	}else{
+		$self->{_menuitem_full}->set_image(
+			Gtk2::Image->new_from_pixbuf(
+				Gtk2::Gdk::Pixbuf->new_from_file_at_size( "$shutter_root/share/shutter/resources/icons/desktop.svg", Gtk2::IconSize->lookup('menu') )
+			)
+		);
+	}
 	$self->{_menu_new}->append( $self->{_menuitem_full} );
 
-	$self->{_menu_new}->append( Gtk2::SeparatorMenuItem->new );
+	#~ $self->{_menu_new}->append( Gtk2::SeparatorMenuItem->new );
+
+	#awindow
+	$self->{_menuitem_awindow} = Gtk2::ImageMenuItem->new_with_mnemonic( $d->get('_Active Window') );
+	if($icontheme->has_icon('gnome-window-manager')){
+		$self->{_menuitem_awindow}->set_image( Gtk2::Image->new_from_icon_name( 'gnome-window-manager', 'menu' ) );	
+	}else{
+		$self->{_menuitem_awindow}->set_image(
+			Gtk2::Image->new_from_pixbuf(
+				Gtk2::Gdk::Pixbuf->new_from_file_at_size( "$shutter_root/share/shutter/resources/icons/sel_window_active.svg", Gtk2::IconSize->lookup('menu') )
+			)
+		);
+	}
+	$self->{_menu_new}->append( $self->{_menuitem_awindow} );
 
 	#window
-	$self->{_menuitem_window} = Gtk2::ImageMenuItem->new_with_mnemonic( $d->get('W_indow') );
+	$self->{_menuitem_window} = Gtk2::ImageMenuItem->new_with_mnemonic( $d->get('Select W_indow') );
 	if($icontheme->has_icon('gnome-window-manager')){
 		$self->{_menuitem_window}->set_image( Gtk2::Image->new_from_icon_name( 'gnome-window-manager', 'menu' ) );	
 	}else{
@@ -506,7 +541,7 @@ sub fct_ret_new_menu {
 	#~ }
 	$self->{_menu_new}->append( $self->{_menuitem_tooltip} );
 
-	$self->{_menu_new}->append( Gtk2::SeparatorMenuItem->new );
+	#~ $self->{_menu_new}->append( Gtk2::SeparatorMenuItem->new );
 
 	#web
 	$self->{_menuitem_web} = Gtk2::ImageMenuItem->new_with_mnemonic( $d->get('_Web') );
@@ -545,8 +580,11 @@ sub fct_ret_actions_menu{
 	
 	$self->{_menu_actions} = Gtk2::Menu->new();
 
+	#~ $self->{_menuitem_reopen_default} = Gtk2::ImageMenuItem->new_with_mnemonic( 
+			#~ sprintf( $d->get('_Open with %s'), ''),
+ 		#~ );
 	$self->{_menuitem_reopen_default} = Gtk2::ImageMenuItem->new_with_mnemonic( 
-			sprintf( $d->get('_Open with %s'), ''),
+			$d->get('_Open with default application')
  		);
 	$self->{_menuitem_reopen_default}->set_image( Gtk2::Image->new_from_stock( 'gtk-open', 'menu' ) );
 	$self->{_menuitem_reopen_default}->set_sensitive(FALSE);
@@ -642,8 +680,11 @@ sub fct_ret_actions_menu_large{
 	
 	$self->{_menu_large_actions} = Gtk2::Menu->new();
 
+	#~ $self->{_menuitem_large_reopen_default} = Gtk2::ImageMenuItem->new_with_mnemonic( 
+			#~ sprintf( $d->get('_Open with %s'), ''),
+ 		#~ );
 	$self->{_menuitem_large_reopen_default} = Gtk2::ImageMenuItem->new_with_mnemonic( 
-			sprintf( $d->get('_Open with %s'), ''),
+			$d->get('_Open with default application')
  		);
 	$self->{_menuitem_large_reopen_default}->set_image( Gtk2::Image->new_from_stock( 'gtk-open', 'menu' ) );
 	$self->{_menuitem_large_reopen_default}->set_sensitive(FALSE);
