@@ -1,6 +1,6 @@
 ###################################################
 #
-#  Copyright (C) 2008, 2009, 2010 Mario Kemper <mario.kemper@googlemail.com> and Shutter Team
+#  Copyright (C) 2008-2011 Mario Kemper <mario.kemper@googlemail.com> and Shutter Team
 #
 #  This file is part of Shutter.
 #
@@ -46,8 +46,8 @@ sub new {
 sub create_toolbar {
 	my $self = shift;
 
-	my $d           = $self->{_common}->get_gettext;
-	my $window      = $self->{_common}->get_mainwindow;
+	my $d = $self->{_common}->get_gettext;
+	my $window = $self->{_common}->get_mainwindow;
 	my $shutter_root = $self->{_common}->get_root;
 
 	#Tooltips
@@ -60,7 +60,7 @@ sub create_toolbar {
 	#--------------------------------------
 	my $image_redoshot = Gtk2::Image->new_from_stock( 'gtk-refresh', 'large-toolbar' );
 	$self->{_redoshot} = Gtk2::ToolButton->new( $image_redoshot, $d->get("Redo") );
-	$self->{_redoshot}->set_is_important (TRUE);
+	#~ $self->{_redoshot}->set_is_important (TRUE);
 
 	$tooltips->set_tip( $self->{_redoshot}, $d->get("Redo last screenshot") );
 
@@ -70,7 +70,7 @@ sub create_toolbar {
 	#--------------------------------------
 	my $image_select;
 	eval{
-		my $ccursor_pb = Gtk2::Gdk::Cursor->new('crosshair')->get_image->scale_simple(Gtk2::IconSize->lookup('large-toolbar'), 'bilinear');
+		my $ccursor_pb = Gtk2::Gdk::Cursor->new('left_ptr')->get_image->scale_simple(Gtk2::IconSize->lookup('large-toolbar'), 'bilinear');
 		$image_select = Gtk2::Image->new_from_pixbuf($ccursor_pb);
 	};
 	if($@){
@@ -99,8 +99,20 @@ sub create_toolbar {
 
 	#button full screen
 	#--------------------------------------
-	my $image_raw = Gtk2::Image->new_from_stock('gtk-fullscreen', 'large-toolbar');
-	$self->{_full} = Gtk2::MenuToolButton->new( $image_raw, $d->get("Full Screen") );
+	my $image_full;
+	if($icontheme->has_icon('user-desktop')){
+		$image_full = Gtk2::Image->new_from_icon_name( 'user-desktop', 'large-toolbar' );		
+	}elsif($icontheme->has_icon('desktop')){
+		$image_full = Gtk2::Image->new_from_icon_name( 'desktop', 'large-toolbar' );		
+	}else{
+		$image_full = Gtk2::Image->new_from_pixbuf(
+			Gtk2::Gdk::Pixbuf->new_from_file_at_size(
+				"$shutter_root/share/shutter/resources/icons/desktop.svg",
+				Gtk2::IconSize->lookup('large-toolbar')
+			)
+		);
+	}
+	$self->{_full} = Gtk2::MenuToolButton->new( $image_full, $d->get("Desktop") );
 	$self->{_full}->set_is_important (TRUE);
 
 	$tooltips->set_tip( $self->{_full}, $d->get("Take a screenshot of your whole desktop") );
@@ -108,6 +120,27 @@ sub create_toolbar {
 
 	#--------------------------------------
 
+	#button active window
+	#--------------------------------------
+	#~ my $image_awindow;
+	#~ if($icontheme->has_icon('gnome-window-manager')){
+		#~ $image_awindow = Gtk2::Image->new_from_icon_name( 'gnome-window-manager', 'large-toolbar' );		
+	#~ }else{
+		#~ $image_awindow = Gtk2::Image->new_from_pixbuf(
+			#~ Gtk2::Gdk::Pixbuf->new_from_file_at_size(
+				#~ "$shutter_root/share/shutter/resources/icons/sel_window_active.svg",
+				#~ Gtk2::IconSize->lookup('large-toolbar')
+			#~ )
+		#~ );
+	#~ }
+	#~ $self->{_awindow} = Gtk2::MenuToolButton->new( $image_awindow, $d->get("Window") );
+	#~ $self->{_awindow}->set_is_important (TRUE);
+	#~ 
+	#~ $tooltips->set_tip( $self->{_awindow}, $d->get("Capture active window") );
+	#~ $self->{_awindow}->set_arrow_tooltip( $tooltips, $d->get("Take a screenshot of a specific window"), '' );
+
+	#--------------------------------------
+
 	#button window
 	#--------------------------------------
 	my $image_window;
@@ -127,8 +160,6 @@ sub create_toolbar {
 	$tooltips->set_tip( $self->{_window}, $d->get("Select a window with your mouse") );
 	$self->{_window}->set_arrow_tooltip( $tooltips, $d->get("Take a screenshot of a specific window"), '' );
 
-	#--------------------------------------
-
 	#button section
 	#--------------------------------------
 	my $image_window_sect;
@@ -245,16 +276,17 @@ sub create_toolbar {
 	#create the toolbar
 	$self->{_toolbar} = Gtk2::Toolbar->new;
 	$self->{_toolbar}->set_show_arrow(FALSE);
-	$self->{_toolbar}->insert( $self->{_redoshot},           -1 );	
+	$self->{_toolbar}->insert( $self->{_redoshot},           -1 );
+	$self->{_toolbar}->insert( Gtk2::SeparatorToolItem->new, -1 );	
 	$self->{_toolbar}->insert( $self->{_select},             -1 );
-	$self->{_toolbar}->insert( Gtk2::SeparatorToolItem->new, -1 );
 	$self->{_toolbar}->insert( $self->{_full},               -1 );
-	$self->{_toolbar}->insert( Gtk2::SeparatorToolItem->new, -1 );
+	#~ $self->{_toolbar}->insert( Gtk2::SeparatorToolItem->new, -1 );
+	#~ $self->{_toolbar}->insert( $self->{_aindow},             -1 );
 	$self->{_toolbar}->insert( $self->{_window},             -1 );
 	$self->{_toolbar}->insert( $self->{_section},            -1 );
 	$self->{_toolbar}->insert( $self->{_menu},               -1 );
 	$self->{_toolbar}->insert( $self->{_tooltip},            -1 );
-	$self->{_toolbar}->insert( Gtk2::SeparatorToolItem->new, -1 );
+	#~ $self->{_toolbar}->insert( Gtk2::SeparatorToolItem->new, -1 );
 	$self->{_toolbar}->insert( $self->{_web},                -1 );
 	#~ $self->{_toolbar}->insert( Gtk2::SeparatorToolItem->new, -1 );
 	$self->{_toolbar}->insert( $expander_r, 				 -1 );
@@ -284,28 +316,44 @@ sub create_btoolbar {
 	$expander_l->set_draw(FALSE);
 	
 	#--------------------------------------
+
+	#button ascending
+	#--------------------------------------
+	my $image_sorta = Gtk2::Image->new_from_stock( 'gtk-sort-ascending', 'small-toolbar' );
+	$self->{_sorta} = Gtk2::ToggleToolButton->new();
+	$self->{_sorta}->set_icon_widget( $image_sorta );
+
+	#--------------------------------------	
 	
 	#button back
 	#--------------------------------------
-	my $image_back = Gtk2::Image->new_from_stock( 'gtk-go-back', 'large-toolbar' );
+	my $image_back = Gtk2::Image->new_from_stock( 'gtk-go-back', 'small-toolbar' );
 	$self->{_back} = Gtk2::ToolButton->new( $image_back, '' );
 
 	#--------------------------------------	
 
 	#button home
 	#--------------------------------------
-	my $image_home = Gtk2::Image->new_from_stock( 'gtk-index', 'large-toolbar' );
+	my $image_home = Gtk2::Image->new_from_stock( 'gtk-index', 'small-toolbar' );
 	$self->{_home} = Gtk2::ToolButton->new( $image_home, '' );
 
 	#--------------------------------------	
 	
 	#button forward
 	#--------------------------------------
-	my $image_forw = Gtk2::Image->new_from_stock( 'gtk-go-forward', 'large-toolbar' );
+	my $image_forw = Gtk2::Image->new_from_stock( 'gtk-go-forward', 'small-toolbar' );
 	$self->{_forw} = Gtk2::ToolButton->new( $image_forw, '' );
 
 	#--------------------------------------	
 
+	#button sort descending
+	#--------------------------------------
+	my $image_sortd = Gtk2::Image->new_from_stock( 'gtk-sort-descending', 'small-toolbar' );
+	$self->{_sortd} = Gtk2::ToggleToolButton->new();
+	$self->{_sortd}->set_icon_widget( $image_sortd );
+
+	#--------------------------------------	
+
 	#expanding separator
 	#--------------------------------------	
 	my $expander_r = Gtk2::SeparatorToolItem->new;
@@ -318,10 +366,13 @@ sub create_btoolbar {
 	$self->{_btoolbar} = Gtk2::Toolbar->new;
 	$self->{_btoolbar}->set_no_show_all(TRUE);
 	$self->{_btoolbar}->set_show_arrow(FALSE);
+	$self->{_btoolbar}->set_style('icons');
 	$self->{_btoolbar}->insert( $expander_l, -1 );
+	$self->{_btoolbar}->insert( $self->{_sorta}, -1 );
 	$self->{_btoolbar}->insert( $self->{_back}, -1 );
 	$self->{_btoolbar}->insert( $self->{_home}, -1 );
 	$self->{_btoolbar}->insert( $self->{_forw}, -1 );
+	$self->{_btoolbar}->insert( $self->{_sortd}, -1 );
 	$self->{_btoolbar}->insert( $expander_r, -1 );
 
 	return $self->{_btoolbar};
