@@ -1,6 +1,6 @@
 ###################################################
 #
-#  Copyright (C) 2008, 2009, 2010 Mario Kemper <mario.kemper@googlemail.com> and Shutter Team
+#  Copyright (C) 2008-2011 Mario Kemper <mario.kemper@googlemail.com> and Shutter Team
 #
 #  This file is part of Shutter.
 #
@@ -36,7 +36,7 @@ use Glib qw/TRUE FALSE/;
 sub new {
 	my $class = shift;
 	
-	my $self = { _sc  => shift, _code => shift, _data => shift };
+	my $self = { _sc  => shift, _code => shift, _data => shift, _extra => shift };
 
 	#############
 	# code = 0 - pointer could not be grabbed - or invalid region
@@ -46,6 +46,7 @@ sub new {
 	# code = 4 - window no longer available
 	# code = 5 - user aborted
 	# code = 6 - gnome-web-photo failed
+	# code = 7 - no window with name xy detected
 	#############	
 
 	bless $self, $class;
@@ -54,7 +55,16 @@ sub new {
 
 sub get_error {
 	my $self = shift;
-	return ($self->{_code}, $self->{_data});
+	return ($self->{_code}, $self->{_data}, $self->{_extra});
+}
+
+sub is_aborted_by_user {
+	my $self = shift;
+	if(defined $self->{_code} && $self->{_code} == 5){
+		return TRUE;
+	}else{
+		return FALSE;
+	}	
 }
 
 sub is_error {
@@ -71,8 +81,9 @@ sub set_error {
 	if (@_) {
 		$self->{_code} = shift;
 		$self->{_data} = shift;
+		$self->{_extra} = shift;
 	}		
-	return ($self->{_code}, $self->{_data});
+	return ($self->{_code}, $self->{_data}, $self->{_extra});
 }
 
 sub show_dialog {
@@ -157,6 +168,16 @@ sub show_dialog {
 		
 		$status_text = $d->get("Unable to capture website");
 			
+	#no window with name $pattern detected
+	}elsif( $self->{_code} == 7 ) {
+		
+		my $name_pattern = $self->{_extra};
+		
+		$response = $sd->dlg_error_message( 
+			sprintf( $d->get( "No window with name pattern %s detected." ), "'".$name_pattern."'"),
+			$d->get( "Error while taking the screenshot." )
+		);
+
 	}
 
 	return ($response, $status_text);
