@@ -1,6 +1,6 @@
 ###################################################
 #
-#  Copyright (C) 2008, 2009, 2010 Mario Kemper <mario.kemper@googlemail.com> and Shutter Team
+#  Copyright (C) 2008-2011 Mario Kemper <mario.kemper@googlemail.com> and Shutter Team
 #
 #  This file is part of Shutter.
 #
@@ -195,7 +195,7 @@ sub select_simple {
 				if ( $event->type eq 'key-press' ) {
 										
 					#toggle zoom window
-					if ( $event->keyval == $Gtk2::Gdk::Keysyms{space} ) {
+					if ( $event->keyval == Gtk2::Gdk->keyval_from_name('space') ) {
 						if ($self->{_zoom_active}){
 							$zoom_window->hide_all;
 							$self->{_zoom_active} = FALSE;
@@ -206,7 +206,7 @@ sub select_simple {
 					}
 						
 					#quit on escape
-					if ( $event->keyval == $Gtk2::Gdk::Keysyms{Escape} ) {
+					if ( $event->keyval == Gtk2::Gdk->keyval_from_name('Escape') ) {
 						if ( $rect_w > 1 ) {
 							#clear the last rectangle
 							$self->{_root}->draw_rectangle( $gc, 0, $rect_x, $rect_y, $rect_w, $rect_h );
@@ -230,24 +230,27 @@ sub select_simple {
 						#hide zoom_window and disable Event Handler
 						$zoom_window->hide;
 						$self->ungrab_pointer_and_keyboard( FALSE, TRUE, FALSE );
-						
+
 						#A short timeout to give the server a chance to
-						#redraw the area that was obscured by our zoom window
-						Glib::Timeout->add ($self->{_hide_time}, sub{
-							($output) = $self->get_pixbuf_from_drawable( $self->{_root}, $rect_x, $rect_y, $rect_w+1, $rect_h+1);
-							
-							#we don't have a useful string for wildcards (e.g. $name)
-							my $d = $self->{_sc}->get_gettext;
-							if($output =~ /Gtk2/){
-								$self->{_action_name} = $d->get("Selection");
-							}
-						
-							#set history object
-							$self->{_history} = Shutter::Screenshot::History->new($self->{_sc}, $self->{_root}, $rect_x, $rect_y, $rect_w+1, $rect_h+1);
-							
-							$self->quit($zoom_window);
+						#redraw the area
+						Glib::Timeout->add ($self->{_hide_time}, sub{		
+							Gtk2->main_quit;
 							return FALSE;	
 						});	
+						Gtk2->main();						
+
+						($output) = $self->get_pixbuf_from_drawable( $self->{_root}, $rect_x, $rect_y, $rect_w+1, $rect_h+1);
+						
+						#we don't have a useful string for wildcards (e.g. $name)
+						my $d = $self->{_sc}->get_gettext;
+						if($output =~ /Gtk2/){
+							$self->{_action_name} = $d->get("Selection");
+						}
+					
+						#set history object
+						$self->{_history} = Shutter::Screenshot::History->new($self->{_sc}, $self->{_root}, $rect_x, $rect_y, $rect_w+1, $rect_h+1);
+						
+						$self->quit($zoom_window);
 						
 					#return error	
 					} else {
