@@ -1,6 +1,6 @@
 ###################################################
 #
-#  Copyright (C) 2008, 2009, 2010 Mario Kemper <mario.kemper@googlemail.com> and Shutter Team
+#  Copyright (C) 2008-2011 Mario Kemper <mario.kemper@googlemail.com> and Shutter Team
 #
 #  This file is part of Shutter.
 #
@@ -28,6 +28,9 @@ use utf8;
 use strict;
 use warnings;
 
+#File operations
+use IO::File();
+
 use Shutter::Screenshot::Main;
 use Shutter::Screenshot::History;
 use Data::Dumper;
@@ -46,12 +49,16 @@ sub new {
 	my $self = $class->SUPER::new( shift, shift, shift, shift );
 
 	#get params
-	$self->{_include_border} 	= shift;
-	$self->{_mode} 				= shift;
-	$self->{_is_hidden}      	= shift;
+	$self->{_include_border}    = shift;
+	$self->{_windowresize}      = shift;
+	$self->{_windowresize_w}    = shift;
+	$self->{_windowresize_h}    = shift;
+	$self->{_hide_time}         = shift;   #a short timeout to give the server a chance to redraw the area that was obscured
+	$self->{_mode}              = shift;
+	$self->{_auto_shape}        = shift;   #shape the window without XShape support	
+	$self->{_is_hidden}         = shift;
 	$self->{_show_visible}      = shift;   #show user-visible windows only when selecting a window
-	$self->{_hide_time}			= shift;   #a short timeout to give the server a chance to redraw the area that was obscured
-	$self->{_ignore_type}	    = shift;   #Ignore possibly wrong type hints
+	$self->{_ignore_type}       = shift;   #Ignore possibly wrong type hints
 
 	#X11 protocol and XSHAPE ext
 	require X11::Protocol;
@@ -73,38 +80,36 @@ sub new {
 		if($compos){
 			$self->{_highlighter}->set_colormap($self->{_main_gtk_window}->get_screen->get_rgba_colormap);
 		}
-	
-		$self->{_highlighter}->double_buffered(FALSE);
+
+		$self->{_highlighter}->set_type_hint('splashscreen');
+		$self->{_highlighter}->set_has_frame(FALSE);
+		$self->{_highlighter}->can_focus(TRUE);
+		$self->{_highlighter}->set_accept_focus(TRUE);
+		$self->{_highlighter}->set_modal(TRUE);
 	    $self->{_highlighter}->set_app_paintable(TRUE);
 	    $self->{_highlighter}->set_decorated(FALSE);
 		$self->{_highlighter}->set_skip_taskbar_hint(TRUE);
 		$self->{_highlighter}->set_skip_pager_hint(TRUE);	    
 	    $self->{_highlighter}->set_keep_above(TRUE);
-	    $self->{_highlighter}->set_accept_focus(FALSE);
-	    $self->{_highlighter}->set_sensitive(FALSE);
 
 		#obtain current colors and font_desc from the main window
 	    my $style 		= $self->{_main_gtk_window}->get_style;
 		my $sel_bg 		= $style->bg('selected');
 		my $sel_tx 		= $style->text('selected');
 		my $font_fam 	= $style->font_desc->get_family;
-		my $font_size 	= $style->font_desc->get_size;
-
-		my $mon 	= $self->get_current_monitor;
-		my $size 	= int( $mon->width * 0.007 );
-		my $size2 	= int( $mon->width * 0.006 );
+		my $font_size 	= $style->font_desc->get_size / Gtk2::Pango->scale;
+		
+		#get current monitor
+		my $mon = $self->get_current_monitor;
 
 		$self->{_highlighter_expose} = $self->{_highlighter}->signal_connect('expose-event' => sub{
-			#remove old handler
-			if(defined $self->{_highlighter_anim}){
-				my $removed = Glib::Source->remove($self->{_highlighter_anim});
-			}
 
 			return FALSE unless $self->{_highlighter}->window;
 
 			print $self->{_c}{'cw'}{'window'}->get_name, "\n" if $self->{_sc}->get_debug; 
 
 			my $text = Glib::Markup::escape_text ($self->{_c}{'cw'}{'window'}->get_name);
+			utf8::decode $text;
 			
 			my $sec_text =  "\n".$self->{_c}{'cw'}{'width'} . "x" . $self->{_c}{'cw'}{'height'};
 
@@ -115,6 +120,15 @@ sub new {
 			#app icon
 			my $icon = $self->{_c}{'cw'}{'window'}->get_icon;
 			
+			#create cairo context
+			my $cr = Gtk2::Gdk::Cairo::Context->create ($self->{_highlighter}->window);
+			
+			#pango layout
+			my $layout = Gtk2::Pango::Cairo::create_layout($cr);
+			$layout->set_width( ($w - $icon->get_width - $font_size * 3) * Gtk2::Pango->scale );
+			$layout->set_alignment('left');
+			$layout->set_wrap('char');
+
 			#warning if there are no subwindows
 			#when we are in section mode and 
 			#a toplevel window was already selected
@@ -128,20 +142,14 @@ sub new {
 					my $d = $self->{_sc}->get_gettext;
 					$text = $d->get("No subwindow detected");
 					$sec_text = "\n".$d->get("Maybe this window is using client-side windows (or similar).\nShutter is not yet able to query the tree information of such windows.");
+					
+					#wrap nicely
+					$layout->set_wrap('word-char');
 				}
 			}
-	
-			#create cairo context
-			my $cr = Gtk2::Gdk::Cairo::Context->create ($self->{_highlighter}->window);
-
-			#pango layout
-			my $layout = Gtk2::Pango::Cairo::create_layout($cr);
-			$layout->set_width( ($w - $icon->get_width - $size * 3) * Gtk2::Pango->scale );
-			$layout->set_alignment('left');
-			$layout->set_wrap('char');
 			
 			#set text
-			$layout->set_markup("<span font_desc=\"$font_fam $size\" weight=\"bold\" foreground=\"#FFFFFF\">$text</span><span font_desc=\"$font_fam $size2\" foreground=\"#FFFFFF\">$sec_text</span>");
+			$layout->set_markup("<span font_desc=\"$font_fam $font_size\" weight=\"bold\" foreground=\"#FFFFFF\">$text</span><span font_desc=\"$font_fam $font_size\" foreground=\"#FFFFFF\">$sec_text</span>");
 
 			#get layout size
 			my ( $lw, $lh ) = $layout->get_pixel_size;
@@ -151,8 +159,8 @@ sub new {
 			$lh = $icon->get_height if $icon->get_height > $lh;
 			
 			#calculate values for rounded/shaped rectangle
-			my $wi = $lw + $size * 3;
-			my $hi = $lh + $size * 2;
+			my $wi = $lw + $font_size * 3;
+			my $hi = $lh + $font_size * 2;
 			my $xi = int( ($w - $wi) / 2 );
 			my $yi = int( ($h - $hi) / 2 );
 			my $ri = 20;
@@ -160,72 +168,54 @@ sub new {
 			#two different ways - compositing or not
 			if($compos){
 				
-				my $counter = 0;
-				$self->{_highlighter_anim} = Glib::Timeout->add (20, sub{
+				#fill window
+				$cr->set_operator('source');
+				$cr->set_source_rgba( $sel_bg->red / 257 / 255, $sel_bg->green / 257 / 255, $sel_bg->blue / 257 / 255, 0.3 );
+				$cr->paint;
+
+				#Parent window with text and icon			
+				if($self->{_c}{'cw'}{'is_parent'}){						
 					
-						return FALSE unless $self->{_highlighter}->window;
-						
-						#increase animation counter
-						$counter++;
-													
-						#fill window
-						$cr->set_operator('source');
-						$cr->set_source_rgba( $sel_bg->red / 257 / 255, $sel_bg->green / 257 / 255, $sel_bg->blue / 257 / 255, $counter * 0.02 );
+					$cr->set_operator('over');
+																			
+					#create small frame (window outlines)
+					$cr->set_source_rgba( $sel_bg->red / 257 / 255, $sel_bg->green / 257 / 255, $sel_bg->blue / 257 / 255, 0.75 );
+					$cr->set_line_width(6);
+					$cr->rectangle (0, 0, $w, $h);
+					$cr->stroke;
+					
+					if($lw <= $w && $lh <= $h){
+					
+						#rounded rectangle to display the window name
+						$cr->move_to( $xi + $ri, $yi );
+						$cr->line_to( $xi + $wi - $ri, $yi );
+						$cr->curve_to( $xi + $wi, $yi, $xi + $wi, $yi, $xi + $wi, $yi + $ri );
+						$cr->line_to( $xi + $wi, $yi + $hi - $ri );
+						$cr->curve_to( $xi + $wi, $yi + $hi, $xi + $wi, $yi + $hi, $xi + $wi - $ri, $yi + $hi );
+						$cr->line_to( $xi + $ri, $yi + $hi );
+						$cr->curve_to( $xi, $yi + $hi, $xi, $yi + $hi, $xi, $yi + $hi - $ri );
+						$cr->line_to( $xi, $yi + $ri );
+						$cr->curve_to( $xi, $yi, $xi, $yi, $xi + $ri, $yi );
+						$cr->fill;	
+
+						#app icon
+						Gtk2::Gdk::Cairo::Context::set_source_pixbuf( $cr, $icon, $xi + $font_size, $yi + $font_size );
 						$cr->paint;
-	
-						#Parent window with text and icon			
-						if($self->{_c}{'cw'}{'is_parent'}){						
-							
-							$cr->set_operator('over');
-																					
-							#create small frame (window outlines)
-							$cr->set_source_rgba( $sel_bg->red / 257 / 255, $sel_bg->green / 257 / 255, $sel_bg->blue / 257 / 255, 0.75 );
-							$cr->set_line_width(6);
-							$cr->rectangle (0, 0, $w, $h);
-							$cr->stroke;
-							
-							if($lw <= $w && $lh <= $h){
-							
-								#rounded rectangle to display the window name
-								$cr->move_to( $xi + $ri, $yi );
-								$cr->line_to( $xi + $wi - $ri, $yi );
-								$cr->curve_to( $xi + $wi, $yi, $xi + $wi, $yi, $xi + $wi, $yi + $ri );
-								$cr->line_to( $xi + $wi, $yi + $hi - $ri );
-								$cr->curve_to( $xi + $wi, $yi + $hi, $xi + $wi, $yi + $hi, $xi + $wi - $ri, $yi + $hi );
-								$cr->line_to( $xi + $ri, $yi + $hi );
-								$cr->curve_to( $xi, $yi + $hi, $xi, $yi + $hi, $xi, $yi + $hi - $ri );
-								$cr->line_to( $xi, $yi + $ri );
-								$cr->curve_to( $xi, $yi, $xi, $yi, $xi + $ri, $yi );
-								$cr->fill;	
-	
-								#app icon
-								Gtk2::Gdk::Cairo::Context::set_source_pixbuf( $cr, $icon, $xi + $size, $yi + $size );
-								$cr->paint;
-								
-								#draw the pango layout
-								$cr->move_to( $xi + $size*2 + $icon->get_width, $yi + $size );
-								Gtk2::Pango::Cairo::show_layout( $cr, $layout );	
+						
+						#draw the pango layout
+						$cr->move_to( $xi + $font_size*2 + $icon->get_width, $yi + $font_size );
+						Gtk2::Pango::Cairo::show_layout( $cr, $layout );	
 
-							}
-
-						}else{
-							#create small frame
-							$cr->set_source_rgba( $sel_bg->red / 257 / 255, $sel_bg->green / 257 / 255, $sel_bg->blue / 257 / 255, 0.75 );
-							$cr->set_line_width(6);
-							$cr->rectangle (0, 0, $w, $h);
-							$cr->stroke;	
-						}
-							
-					#quit animation	
-					if($counter == 15){
-						return FALSE;
-					}else{
-						return TRUE;	
 					}
-	
-					return FALSE;	
-				});	
-			
+
+				}else{
+					#create small frame
+					$cr->set_source_rgba( $sel_bg->red / 257 / 255, $sel_bg->green / 257 / 255, $sel_bg->blue / 257 / 255, 0.75 );
+					$cr->set_line_width(6);
+					$cr->rectangle (0, 0, $w, $h);
+					$cr->stroke;	
+				}
+
 			#no compositing
 			}else{
 
@@ -239,11 +229,11 @@ sub new {
 					
 					if($lw <= $w && $lh <= $h){
 						#app icon
-						Gtk2::Gdk::Cairo::Context::set_source_pixbuf( $cr, $icon, $xi + $size, $yi + $size );
+						Gtk2::Gdk::Cairo::Context::set_source_pixbuf( $cr, $icon, $xi + $font_size, $yi + $font_size );
 						$cr->paint;
 						
 						#draw the pango layout
-						$cr->move_to( $xi + $size*2 + $icon->get_width, $yi + $size );
+						$cr->move_to( $xi + $font_size*2 + $icon->get_width, $yi + $font_size );
 						Gtk2::Pango::Cairo::show_layout( $cr, $layout );
 					}	
 				
@@ -310,23 +300,84 @@ sub get_shape {
 
 	my ($ordering, @r) = $self->{_x11}->ShapeGetRectangles($self->find_wm_window($xid), 'Bounding');
 	
+	my $manually_shaped = FALSE;
+	#create shape manually when option is set
+	if (scalar @r <= 1 && defined $self->{_auto_shape} && $self->{_auto_shape}){
+		
+		my $shf = Shutter::App::HelperFunctions->new( $self->{_sc} );
+		
+		my $shape_path = undef;
+		$shape_path = $self->{_sc}->get_root . "/share/shutter/resources/conf/shape.conf" if $shf->file_exists($self->{_sc}->get_root . "/share/shutter/resources/conf/shape.conf");
+		$shape_path = "$ENV{'HOME'}/.shutter/shape.conf" if $shf->file_exists("$ENV{'HOME'}/.shutter/shape.conf");
+		
+		if(defined $shape_path && $shape_path){
+			
+			my @fregion;
+			
+			my $fh = new IO::File;
+			if ($fh->open("< $shape_path")) {
+				while( my $line = <$fh> ){
+					#skip on comments
+					next if $line =~ /^#/;
+					chomp($line);
+					push @fregion, $line;
+				}
+				$fh->close;
+			}else{
+				print "Unable to open file $shape_path" if $self->{_sc}->get_debug;
+				return $orig;
+			}
+			
+			print "Window shape not detected - using $shape_path\n" if $self->{_sc}->get_debug;
+			
+			#remove current entry
+			pop @r;
+			
+			my $width = $orig->get_width;
+			my $height = $orig->get_height;
+						
+			foreach my $line(@fregion){
+				$line =~ s/width/$width/;
+				$line =~ s/height/$height/;
+				$line =~ s/(\d+)-(\d+)/$1-$2/eg;
+				my @temp = split(' ', $line);
+				push @r, \@temp;
+			}
+			
+			$manually_shaped = TRUE;
+			
+		}else{
+			
+			print "Unable to locate shape.conf\n" if $self->{_sc}->get_debug;
+			
+		}
+		
 	#do nothing if there are no
-	#shape rectangles (or only one)
-	return $orig if scalar @r <= 1;
+	#shape rectangles (or only one)		
+	}elsif(scalar @r <= 1){
+		return $orig;
+	}
 							
 	#create a region from the bounding rectangles
 	my $bregion = Gtk2::Gdk::Region->new;					
 	foreach my $r (@r){
 		my @rect =  @{$r};
 		
-		#adjust rectangle if window is only partially visible
-		if($l_cropped){
-			$rect[2] -= $l_cropped - $rect[0]; 
-			$rect[0] = 0;
-		}
-		if($t_cropped){
-			$rect[3] -= $t_cropped - $rect[1]; 
-			$rect[1] = 0;
+		next unless defined $rect[0];
+		next unless defined $rect[1];
+		next unless defined $rect[2];
+		next unless defined $rect[3];
+		
+		unless($manually_shaped){
+			#adjust rectangle if window is only partially visible
+			if($l_cropped){
+				$rect[2] -= $l_cropped - $rect[0]; 
+				$rect[0] = 0;
+			}
+			if($t_cropped){
+				$rect[3] -= $t_cropped - $rect[1]; 
+				$rect[1] = 0;
+			}
 		}
 		
 		print "Current $rect[0],$rect[1],$rect[2],$rect[3]\n" if $self->{_sc}->get_debug;
@@ -365,27 +416,58 @@ sub get_shape {
 }	
 
 sub get_window_size {
-	my ( $self, $wnck_window, $gdk_window, $border ) = @_;
+	my ( $self, $wnck_window, $gdk_window, $border, $no_resize ) = @_;
 
-	my ( $xp, $yp, $wp, $hp ) = $wnck_window->get_geometry;
-	if ($border) {
+	#windowresize is active
+	if($self->{_mode} eq "window" || $self->{_mode} eq "tray_window" || $self->{_mode} eq "awindow" || $self->{_mode} eq "tray_awindow"){
+		unless($no_resize){
+			if(defined $self->{_windowresize} && $self->{_windowresize}) {
+				
+				#windows can usually not be resized when maximized
+				if($wnck_window->is_maximized){
+					$wnck_window->unmaximize;
+				}
 
-		#~ #find wm_window
-		#~ my $wm_window = Gtk2::Gdk::Window->foreign_new( $self->find_wm_window( $wnck_window->get_xid ) );
-		#~ $gdk_window = $wm_window if $wm_window;
+				$self->quit_eventh_only;
 
-		#get_size of it
-		my ( $xp2, $yp2, $wp2, $hp2 ) = $gdk_window->get_geometry;
-		( $xp2, $yp2 ) = $gdk_window->get_origin;
-
-		#check the correct rect
-		if (   $xp2 + $wp2 > $xp + $wp && $yp2 + $hp2 > $yp + $hp ) {
-			( $xp, $yp, $wp, $hp ) = ( $xp2, $yp2, $wp2, $hp2 );
+				Glib::Timeout->add ($self->{_hide_time}, sub{		
+					Gtk2->main_quit;
+					return FALSE;	
+				});	
+				Gtk2->main();
+				
+				my ($xc, $yc, $wc, $hc) = $self->get_window_size($wnck_window, $gdk_window, $border, TRUE);
+				
+				if(defined $self->{_windowresize_w} && $self->{_windowresize} > 0){
+					$wc = $self->{_windowresize_w};
+				}
+				
+				if(defined $self->{_windowresize_h} && $self->{_windowresize_h} > 0){
+					$hc = $self->{_windowresize_h};
+				}
+				
+				if($border){
+					$wnck_window->set_geometry ('current', [qw/width height/], $xc, $yc, $wc, $hc);		
+				}else{
+					$gdk_window->resize ($wc, $hc);
+				}
+					
+				Glib::Timeout->add ($self->{_hide_time}, sub{		
+					Gtk2->main_quit;
+					return FALSE;	
+				});	
+				Gtk2->main();
+			}
 		}
+	}
 
+	#calculate size of the window
+	my ( $xp, $yp, $wp, $hp ) = (0, 0, 0, 0);
+	if ($border) {
+		( $xp, $yp, $wp, $hp ) = $wnck_window->get_geometry;
 	} else {
-		( $wp, $hp ) 	= $gdk_window->get_size;
-		( $xp, $yp )	= $gdk_window->get_origin;
+		( $xp, $yp, $wp, $hp ) = $gdk_window->get_geometry;
+		( $xp, $yp ) = $gdk_window->get_origin;
 	}
 
 	return ( $xp, $yp, $wp, $hp );
@@ -398,13 +480,7 @@ sub update_highlighter {
 	my $width	= shift;
 	my $height	= shift;
 
-	#two different methods to hide the window before moving it
-	#(to avoid flicker)
-	if (Gtk2->CHECK_VERSION( 2, 12, 0 )) {
-		$self->{_highlighter}->set_opacity(0);	
-	}else{
-		$self->{_highlighter}->hide;	
-	}
+	$self->{_highlighter}->hide;
 	
 	if(defined $self->{_c}{'cw'}{'gdk_window'} && defined $self->{_c}{'cw'}{'window'}){
 
@@ -413,13 +489,10 @@ sub update_highlighter {
 		$self->{_highlighter}->resize($width+6, $height+6);
 		
 		#and show highlighter window at current cursor position		
-		$self->{_highlighter}->show;
+		$self->{_highlighter}->show_all;
+		$self->{_highlighter}->present;
 
-		if (Gtk2->CHECK_VERSION( 2, 12, 0 )) {
-			$self->{_notifications_timeout} = Glib::Timeout->add (100, sub{
-				$self->{_highlighter}->set_opacity(1);
-			});		
-		}
+		Gtk2::Gdk->keyboard_grab( $self->{_highlighter}->window, 0, Gtk2->get_current_event_time );
 	
 		#save last window objects
 		$self->{_c}{'lw'}{'window'} 	= $self->{_c}{'cw'}{'window'};
@@ -452,7 +525,7 @@ sub find_current_parent_window {
 				next if ( $cwdow->get_xid == $self->{_main_gtk_window}->window->get_xid );
 			}
 	
-			my ( $xp, $yp, $wp, $hp ) = $self->get_window_size( $cwdow, $drawable, $self->{_include_border} );
+			my ( $xp, $yp, $wp, $hp ) = $self->get_window_size( $cwdow, $drawable, $self->{_include_border}, TRUE );
 	
 			my $wr = Gtk2::Gdk::Region->rectangle(
 				Gtk2::Gdk::Rectangle->new( $xp, $yp, $wp, $hp ) );
@@ -579,25 +652,12 @@ sub find_active_window {
 		
 		if ( defined $wnck_window ) {
 						
-			#size
-			my ( $xp, $yp, $wp, $hp ) = $self->get_window_size( $wnck_window, $gdk_window, $self->{_include_border} );
-
-			$self->{_c}{'cw'}{'window'}     = $wnck_window;
-			$self->{_c}{'cw'}{'gdk_window'} = $gdk_window;
-			$self->{_c}{'cw'}{'x'} 			= $xp;
-			$self->{_c}{'cw'}{'y'} 			= $yp;
-			$self->{_c}{'cw'}{'width'} 		= $wp;
-			$self->{_c}{'cw'}{'height'} 	= $hp;
-			$self->{_c}{'cw'}{'is_parent'} 	= TRUE;
-	
-			#~ print $self->{_c}{'cw'}{'x'}, " - ",			 			
-				  #~ $self->{_c}{'cw'}{'y'}, " - ", 			
-				  #~ $self->{_c}{'cw'}{'width'}, " - ", 		
-				  #~ $self->{_c}{'cw'}{'height'}, " \n " if $self->{_sc}->get_debug; 
+			return ($wnck_window, $gdk_window);
+			
 		}		  				
 	}
 	
-	return TRUE;	
+	return FALSE;	
 }
 
 sub find_region_for_window_type {
@@ -734,7 +794,10 @@ sub window {
 
 	#grab pointer and keyboard
 	#when mode is section or window 
-	unless($self->{_mode} eq "menu" || $self->{_mode} eq "tray_menu" || $self->{_mode} eq "tooltip" || $self->{_mode} eq "tray_tooltip"){
+	unless($self->{_mode} eq "menu" || $self->{_mode} eq "tray_menu" || $self->{_mode} eq "tooltip" || $self->{_mode} eq "tray_tooltip" || $self->{_mode} eq "awindow" || $self->{_mode} eq "tray_awindow"){
+		
+		$self->{_highlighter}->realize;
+		
 		my $grab_counter = 0;
 		while ( !Gtk2::Gdk->pointer_is_grabbed && $grab_counter < 100 ) {
 			Gtk2::Gdk->pointer_grab(
@@ -749,9 +812,10 @@ sub window {
 				Gtk2::Gdk::Cursor->new('GDK_HAND2'),
 				Gtk2->get_current_event_time
 			);
-			Gtk2::Gdk->keyboard_grab( $self->{_root}, 0, Gtk2->get_current_event_time );
+			Gtk2::Gdk->keyboard_grab( $self->{_highlighter}->window, 0, Gtk2->get_current_event_time );
 			$grab_counter++;
 		}
+
 	}
 
 	#init
@@ -777,8 +841,8 @@ sub window {
 	$initevent->window($self->{_root});
 	$initevent->x($initx);
 	$initevent->y($inity);
-	
-	if ( Gtk2::Gdk->pointer_is_grabbed ) {
+		
+	if ( Gtk2::Gdk->pointer_is_grabbed && !($self->{_mode} eq "menu" || $self->{_mode} eq "tray_menu" || $self->{_mode} eq "tooltip" || $self->{_mode} eq "tray_tooltip" || $self->{_mode} eq "awindow" || $self->{_mode} eq "tray_awindow") ) {
 
 		#simulate mouse movement
 		$self->select_window($initevent, $active_workspace);
@@ -792,7 +856,7 @@ sub window {
 				if ( $event->type eq 'key-press' ) {
 					next unless defined $event->keyval;
 					
-					if ( $event->keyval == $Gtk2::Gdk::Keysyms{Escape} ) {
+					if ( $event->keyval == Gtk2::Gdk->keyval_from_name('Escape') ) {
 
 						#destroy highlighter window
 						$self->{_highlighter}->destroy;
@@ -812,11 +876,23 @@ sub window {
 				
 				#BUTTON-RELEASE				
 				} elsif ( $event->type eq 'button-release' ) {
-					print "Type: " . $event->type . "\n"
-						if ( defined $event && $self->{_sc}->get_debug );
+					print "Type: " . $event->type . "\n" if ( defined $event && $self->{_sc}->get_debug );
+
+					my ( $xp, $yp, $wp, $hp, $xc, $yc, $wc, $hc ) = (0, 0, 0, 0, 0, 0, 0, 0);
 
 					if ( defined $self->{_c}{'lw'} && $self->{_c}{'lw'}{'gdk_window'} ) {
+						
+						#size (we need to do this again because of autoresizing)
+						if ( ( $self->{_mode} eq "window" || $self->{_mode} eq "tray_window" ||  $self->{_mode} eq "awindow"  || $self->{_mode} eq "tray_awindow" ) ) {
+							( $xc, $yc, $wc, $hc ) = $self->get_window_size( $self->{_c}{'lw'}{'window'}, $self->{_c}{'lw'}{'gdk_window'}, $self->{_include_border}, TRUE );
+							( $xp, $yp, $wp, $hp ) = $self->get_window_size( $self->{_c}{'lw'}{'window'}, $self->{_c}{'lw'}{'gdk_window'}, $self->{_include_border} );
 
+							$self->{_c}{'cw'}{'x'} 			= $xp;
+							$self->{_c}{'cw'}{'y'} 			= $yp;
+							$self->{_c}{'cw'}{'width'} 		= $wp;
+							$self->{_c}{'cw'}{'height'} 	= $hp;
+						}
+						
 						#focus selected window (maybe it is hidden)
 						$self->{_c}{'lw'}{'gdk_window'}->focus($event->time);
 						Gtk2::Gdk->flush;						
@@ -847,62 +923,77 @@ sub window {
 						return TRUE;
 					}
 
+					#stop event handler
+					$self->quit_eventh_only;
+
 					#destroy highlighter window
 					$self->{_highlighter}->destroy;
-
-					#disable Event Handler
-					$self->ungrab_pointer_and_keyboard( FALSE, TRUE, FALSE );
 					
 					#A short timeout to give the server a chance to
 					#redraw the area
-					Glib::Timeout->add ($self->{_hide_time}, sub{
-						
-						my ($output_new, $l_cropped, $r_cropped, $t_cropped, $b_cropped) = 
-							$self->get_pixbuf_from_drawable(
-								$self->{_root},
-								$self->{_c}{'cw'}{'x'},
-								$self->{_c}{'cw'}{'y'},
-								$self->{_c}{'cw'}{'width'},
-								$self->{_c}{'cw'}{'height'}
-							);
+					Glib::Timeout->add ($self->{_hide_time}, sub{		
+						Gtk2->main_quit;
+						return FALSE;	
+					});	
+					Gtk2->main();
+					
+					my ($output_new, $l_cropped, $r_cropped, $t_cropped, $b_cropped) = 
+						$self->get_pixbuf_from_drawable(
+							$self->{_root},
+							$self->{_c}{'cw'}{'x'},
+							$self->{_c}{'cw'}{'y'},
+							$self->{_c}{'cw'}{'width'},
+							$self->{_c}{'cw'}{'height'}
+						);
 
-						#save return value to current $output variable 
-						#-> ugly but fastest and safest solution now
-						$output = $output_new;
-													
-						#respect rounded corners of wm decorations (metacity for example - does not work with compiz currently)	
-						if($self->{_x11}{ext_shape} && $self->{_include_border}){
-							my $xid = $self->{_c}{ 'cw' }{ 'gdk_window' }->get_xid;
-							#do not try this for child windows
-							foreach my $win ($self->{_wnck_screen}->get_windows){
-								if($win->get_xid == $xid){
-									$output = $self->get_shape($xid, $output, $l_cropped, $r_cropped, $t_cropped, $b_cropped);				
-									last;
+					#save return value to current $output variable 
+					#-> ugly but fastest and safest solution now
+					$output = $output_new;
+												
+					#respect rounded corners of wm decorations (metacity for example - does not work with compiz currently)	
+					if($self->{_x11}{ext_shape} && $self->{_include_border}){
+						my $xid = $self->{_c}{ 'cw' }{ 'gdk_window' }->get_xid;
+						#do not try this for child windows
+						foreach my $win ($self->{_wnck_screen}->get_windows){
+							if($win->get_xid == $xid){
+								$output = $self->get_shape($xid, $output, $l_cropped, $r_cropped, $t_cropped, $b_cropped);				
+								last;
+							}
+						}
+					}
+
+					#restore window size when autoresizing was used
+					if($self->{_mode} eq "window" || $self->{_mode} eq "tray_window" || $self->{_mode} eq "awindow" || $self->{_mode} eq "tray_awindow"){
+						if(defined $self->{_windowresize} && $self->{_windowresize}) {
+							if($wc != $wp || $hc != $hp){
+								if($self->{_include_border}){
+									$self->{_c}{'lw'}{'window'}->set_geometry ('current', [qw/width height/], $xc, $yc, $wc, $hc);		
+								}else{
+									$self->{_c}{'lw'}{'gdk_window'}->resize ($wc, $hc);
 								}
 							}
 						}
+					}
 
-						#set name of the captured window
-						#e.g. for use in wildcards
-						if($output =~ /Gtk2/ && defined $self->{_c}{'cw'}{'window'}){
-							$self->{_action_name} = $self->{_c}{'cw'}{'window'}->get_name;
-						}
+					#set name of the captured window
+					#e.g. for use in wildcards
+					if($output =~ /Gtk2/ && defined $self->{_c}{'cw'}{'window'}){
+						$self->{_action_name} = $self->{_c}{'cw'}{'window'}->get_name;
+					}
 
-						#set history object
-						$self->{_history} = Shutter::Screenshot::History->new($self->{_sc}, 
-								$self->{_root}, 
-								$self->{_c}{'cw'}{'x'}, 
-								$self->{_c}{'cw'}{'y'},
-								$self->{_c}{'cw'}{'width'},
-								$self->{_c}{'cw'}{'height'},
-								undef,
-								$self->{_c}{'cw'}{'window'}->get_xid,
-								$self->{_c}{'cw'}{'gdk_window'}->get_xid
-						);
+					#set history object
+					$self->{_history} = Shutter::Screenshot::History->new($self->{_sc}, 
+							$self->{_root}, 
+							$self->{_c}{'cw'}{'x'}, 
+							$self->{_c}{'cw'}{'y'},
+							$self->{_c}{'cw'}{'width'},
+							$self->{_c}{'cw'}{'height'},
+							undef,
+							$self->{_c}{'cw'}{'window'}->get_xid,
+							$self->{_c}{'cw'}{'gdk_window'}->get_xid
+					);
 
-						$self->quit;
-						return FALSE;	
-					});	
+					$self->quit;
 															
 				#MOTION-NOTIFY											
 				} elsif ( $event->type eq 'motion-notify' ) {
@@ -923,13 +1014,30 @@ sub window {
 	#pointer not grabbed	
 	} else {    
 		
-		$self->ungrab_pointer_and_keyboard( FALSE, FALSE, FALSE );
 		$output = 0;
 
-		if ( ( $self->{_mode} eq "window" || $self->{_mode} eq "tray_window" ) ) {
+		my ( $xp, $yp, $wp, $hp, $xc, $yc, $wc, $hc ) = (0, 0, 0, 0, 0, 0, 0, 0);
+
+		if ( ( $self->{_mode} eq "window" || $self->{_mode} eq "tray_window" ||  $self->{_mode} eq "awindow"  || $self->{_mode} eq "tray_awindow" ) ) {
 
 			#and select current parent window
-			$self->find_active_window;
+			my ($wnck_window, $gdk_window) = $self->find_active_window;
+			
+			if(defined $wnck_window && $wnck_window && defined $gdk_window && $gdk_window){
+
+				#get_size of it
+				( $xc, $yc, $wc, $hc ) = $self->get_window_size($wnck_window, $gdk_window, $self->{_include_border}, TRUE);
+				( $xp, $yp, $wp, $hp ) = $self->get_window_size($wnck_window, $gdk_window, $self->{_include_border});
+			
+				$self->{_c}{'cw'}{'window'}     = $wnck_window;
+				$self->{_c}{'cw'}{'gdk_window'} = $gdk_window;
+				$self->{_c}{'cw'}{'x'} 			= $xp;
+				$self->{_c}{'cw'}{'y'} 			= $yp;
+				$self->{_c}{'cw'}{'width'} 		= $wp;
+				$self->{_c}{'cw'}{'height'} 	= $hp;
+				$self->{_c}{'cw'}{'is_parent'} 	= TRUE;
+			
+			}
 
 		}elsif ( ( $self->{_mode} eq "menu" || $self->{_mode} eq "tray_menu" ) ) {
 
@@ -990,7 +1098,7 @@ sub window {
 		#respect rounded corners of wm decorations 
 		#(metacity for example - does not work with compiz currently)
 		#only if toplevel window was selected
-		if ( ( $self->{_mode} eq "window" || $self->{_mode} eq "tray_window" ) ) {
+		if ( ( $self->{_mode} eq "window" || $self->{_mode} eq "tray_window" ||  $self->{_mode} eq "awindow"  || $self->{_mode} eq "tray_awindow" ) ) {
 			if($self->{_x11}{ext_shape} && $self->{_include_border}){
 				my $xid = $self->{_c}{ 'cw' }{ 'gdk_window' }->get_xid;
 				#do not try this for child windows
@@ -1003,11 +1111,24 @@ sub window {
 			}
 		}
 
+		#restore window size when autoresizing was used
+		if($self->{_mode} eq "window" || $self->{_mode} eq "tray_window" || $self->{_mode} eq "awindow" || $self->{_mode} eq "tray_awindow"){
+			if(defined $self->{_windowresize} && $self->{_windowresize}) {
+				if($wc != $wp || $hc != $hp){
+					if($self->{_include_border}){
+						$self->{_c}{'cw'}{'window'}->set_geometry ('current', [qw/width height/], $xc, $yc, $wc, $hc);		
+					}else{
+						$self->{_c}{'cw'}{'gdk_window'}->resize ($wc, $hc);
+					}
+				}
+			}
+		}
+
 		#set name of the captured window
 		#e.g. for use in wildcards
 		my $d = $self->{_sc}->get_gettext;
 		
-		if ( ( $self->{_mode} eq "window" || $self->{_mode} eq "tray_window" ) ) {
+		if ( ( $self->{_mode} eq "window" || $self->{_mode} eq "tray_window" ||  $self->{_mode} eq "awindow"  || $self->{_mode} eq "tray_awindow" ) ) {
 
 			if($output =~ /Gtk2/ && defined $self->{_c}{'cw'}{'window'}){
 				$self->{_action_name} = $self->{_c}{'cw'}{'window'}->get_name;
@@ -1086,16 +1207,26 @@ sub redo_capture {
 			if(defined $gdk_window && defined $wnck_window){
 	
 				#store size
-				my ( $xp, $yp, $wp, $hp ) = (0, 0, 0, 0);
+				my ( $xp, $yp, $wp, $hp, $xc, $yc, $wc, $hc ) = (0, 0, 0, 0, 0, 0, 0, 0);
 	
 				if($self->{_mode} eq "section" || $self->{_mode} eq "tray_section" ){
 	
-					( $wp, $hp ) = $gdk_window->get_size;
+					( $xp, $yp, $wp, $hp ) = $gdk_window->get_geometry;
 					( $xp, $yp ) = $gdk_window->get_origin;
 					
-				}elsif($self->{_mode} eq "window" || $self->{_mode} eq "tray_window" ){
+					#find parent window
+					my $pxid = $self->find_wm_window($gxid);
+					my $parent = Gtk2::Gdk::Window->foreign_new( $pxid );
+					if(defined $parent && $parent){
+						#and focus parent window (maybe it is hidden)
+						$parent->focus(Gtk2->get_current_event_time);
+						Gtk2::Gdk->flush;
+					}
+									
+				}elsif($self->{_mode} eq "window" || $self->{_mode} eq "tray_window" || $self->{_mode} eq "awindow" || $self->{_mode} eq "tray_awindow"){
 	
 					#get_size of it
+					( $xc, $yc, $wc, $hc ) = $self->get_window_size($wnck_window, $gdk_window, $self->{_include_border}, TRUE);
 					( $xp, $yp, $wp, $hp ) = $self->get_window_size($wnck_window, $gdk_window, $self->{_include_border});
 								
 				}
@@ -1103,26 +1234,39 @@ sub redo_capture {
 				#focus selected window (maybe it is hidden)
 				$gdk_window->focus(Gtk2->get_current_event_time);
 				Gtk2::Gdk->flush;	
-	
+
 				#A short timeout to give the server a chance to
 				#redraw the area
-				Glib::Timeout->add ($self->{_hide_time}, sub{
-	
-					my ($output_new, $l_cropped, $r_cropped, $t_cropped, $b_cropped) = $self->get_pixbuf_from_drawable($self->{_root}, $xp, $yp, $wp, $hp);
-	
-					#save return value to current $output variable 
-					#-> ugly but fastest and safest solution now				
-					$output = $output_new;
-	
-					if($self->{_mode} eq "window" || $self->{_mode} eq "tray_window" ){
-						$output = $self->get_shape($gxid, $output, $l_cropped, $r_cropped, $t_cropped, $b_cropped);
-					}
-	
-					$self->quit;
+				Glib::Timeout->add ($self->{_hide_time}, sub{		
+					Gtk2->main_quit;
 					return FALSE;	
-				});					
-				
+				});	
 				Gtk2->main();
+		
+				my ($output_new, $l_cropped, $r_cropped, $t_cropped, $b_cropped) = $self->get_pixbuf_from_drawable($self->{_root}, $xp, $yp, $wp, $hp);
+
+				#save return value to current $output variable 
+				#-> ugly but fastest and safest solution now				
+				$output = $output_new;
+
+				if($self->{_mode} eq "window" || $self->{_mode} eq "tray_window" || $self->{_mode} eq "awindow" || $self->{_mode} eq "tray_awindow"){
+					$output = $self->get_shape($gxid, $output, $l_cropped, $r_cropped, $t_cropped, $b_cropped);
+				}
+				
+				#restore window size when autoresizing was used
+				if($self->{_mode} eq "window" || $self->{_mode} eq "tray_window" || $self->{_mode} eq "awindow" || $self->{_mode} eq "tray_awindow"){
+					if(defined $self->{_windowresize} && $self->{_windowresize}) {
+						if($wc != $wp || $hc != $hp){
+							if($self->{_include_border}){
+								$wnck_window->set_geometry ('current', [qw/width height/], $xc, $yc, $wc, $hc);		
+							}else{
+								$gdk_window->resize ($wc, $hc);
+							}
+						}
+					}
+				}
+
+				$self->quit_eventh_only;
 					
 			}else{
 				warn "WARNING: Could not get window with id $gxid\n";
@@ -1162,5 +1306,12 @@ sub quit {
 
 }
 
+sub quit_eventh_only {
+	my $self = shift;
+	
+	$self->ungrab_pointer_and_keyboard( FALSE, TRUE, FALSE );
+	Gtk2::Gdk->flush;
+
+}
 
 1;
